@@ -8,147 +8,62 @@
 #' @import tidyverse
 #' @importFrom stats complete.cases
 #' @param raw_data \code{data.frame} containing data for analysis
-#' @param meta_data \code{data.frame} mapping variable names to their roles (i.e. POOL)
-#' @param model_table \code{data.frame} as created in the \code{build_model_table} function
 #' @param verbose A boolean to specify whether to print warnings
 #' @param dv string specifying the dependent variable name
+#' @param pool_var string specifying the pool variable name (e.g. 'country')
 #' @return \code{list} containing a \code{tibble} of normalised data and a \code{tibble} of pool means
+#' @examples
+#' pooled_data = read_xcsv(
+#'  verbose = FALSE,
+#'  file = "https://raw.githubusercontent.com/paladinic/data/main/pooled%20data.csv")
+#'
+#' norm_data = apply_normalisation(
+#'  raw_data = pooled_data,
+#'  pool_var = 'country',
+#'  dv = 'amazon')
 apply_normalisation = function(raw_data = NULL,
-                               meta_data = NULL,
-                               model_table = NULL,
+                               pool_var = NULL,
                                dv = NULL,
                                verbose = FALSE){
+
+  # checks  ####
+
   if(!is.logical(verbose)){
     message("Warning: verbose provided must be logical (TRUE or FALSE). Setting to False.")
     verbose = FALSE
   }
 
-  # if no raw_data is provided, end by returning NULL
+  # check raw data
   if (is.null(raw_data)) {
-    if(verbose){
-      message("Error: No raw_data provided. Returning NULL.")
-    }
+    message("Error: No raw_data provided. Returning NULL.")
     return(NULL)
   }
-  # if raw_data is not a dataframe
   if(!is.data.frame(raw_data)){
-    if(verbose){
-      message("Error: raw_data must be a data.frame. Returning NULL.")
-    }
+    message("Error: raw_data must be a data.frame. Returning NULL.")
     return(NULL)
   }
 
-
-  # if no meta_data is provided, end by returning raw_data
-  if (is.null(meta_data)) {
-    if(verbose){
-      message("Error: No meta_data provided. Returning original raw_data.")
-    }
+  # check dv
+  if(is.null(dv)){
+    message("Error: No dv provided. Returning raw_data")
     return(raw_data)
   }
-  # if meta_data is not a dataframe
-  if(!is.data.frame(meta_data)){
-    if(verbose){
-      message("Error: meta_data must be a data.frame. Returning original raw_data.")
-    }
+  if(!(dv %in% colnames(raw_data))){
+    message("Error: dv provided not found in raw_data. Returning raw_data")
     return(raw_data)
   }
 
-
-  # if the meta_data table doesnt contain a variables column, end by returning raw_data
-  if(!all(c("variable","meta") %in% colnames(meta_data))){
-    if(verbose){
-      message("Error: meta_data does not contain a 'variable' and a 'meta' columns. Returning original raw_data.")
-    }
+  # check pool_var
+  if(is.null(pool_var)){
+    message("Error: No pool_var provided. Returning original raw_data.")
     return(raw_data)
   }
-  # get all variables in meta_data
-  variable = meta_data$variable
-
-  # get data column names
-  data_variables = colnames(raw_data)
-
-  # get the pool variable
-  pool_variable = TRY({
-    variable[toupper(meta_data$meta) == "POOL"]
-  })
-  pool_mean = NULL
-
-  # check if a pool variable is provided
-  ## RETURNING RAW_DATA IF NO POOL_VARIABLE provided??
-  if(is.null(pool_variable) | length(pool_variable) == 0) {
-    if(verbose){
-      message("Warning: no POOL variable found in meta_data. A 'total_pool' variable was added.")
-    }
-
-    # if not provided create a unique one
-    pool_variable = "total_pool"
-
-    # add the pool variable to data
-    raw_data = cbind(raw_data, total_pool = pool_variable)
-
-    # get new data column names
-    data_variables = colnames(raw_data)
-  }
-
-  # check if more than 1 pool variable is provided
-  if (length(pool_variable) > 1) {
-    if(verbose){
-      message("Error: More than 1 pool variable provided")
-    }
+  if(!(pool_var %in% colnames(raw_data))){
+    message("Error: pool variable not found in raw_data. Returning original raw_data.")
     return(raw_data)
   }
 
-  # check if pool variable in data variables
-  if (!(pool_variable %in% data_variables)) {
-    if(verbose){
-      message("Error: POOL variable not found in raw_data. Returning original raw_data.")
-    }
-    return(raw_data)
-  }
-
-  # check if ivs and dv are provided to select only relevant variables
-  if(is.null(model_table)){
-    if(verbose){
-      message("Warning: Normalising all raw_data as no model_table is provided.")
-    }
-  }else{
-    if(!is.data.frame(model_table)){
-      if(verbose){
-        message("Warning: model_table must be a data.frame. Normalising all raw_data.")
-      }
-    }else{
-      if(!is.null(dv)){
-
-        ivs = model_table$variable %>%
-          unique()
-
-        # check if ivs dv are in data
-        if(all(c(ivs) %in% colnames(raw_data))){
-          if(dv %in% colnames(raw_data)){
-
-            # keep only relevant variables
-            raw_data = raw_data[,c(pool_variable,dv,ivs)]
-
-          }else{
-            if(verbose){
-              message("Warning: dependent variable (dv) not found in raw_data. Normalising all raw_data.")
-            }
-          }
-        }else{
-          if(verbose){
-            message("Warning: variables from model_table not found in raw_data. Normalising all raw_data.")
-          }
-        }
-      }else{
-        if(verbose){
-          message("Warning: dependent variable (dv) not provided. Normalising all raw_data.")
-        }
-      }
-    }
-  }
-
-  # in raw data, check for and drop NAs
+  # check for NAs
   if(any(complete.cases(raw_data))) {
     if(verbose){
       message("Warning: NA's found in raw_data will be dropped.")
@@ -156,38 +71,23 @@ apply_normalisation = function(raw_data = NULL,
     raw_data = raw_data[complete.cases(raw_data), ]
   }
 
+  # process ####
+  pool_mean = raw_data %>%
+    group_by(!!sym(pool_var)) %>%
+    summarise(mean = mean(!!sym(dv))) %>%
+    rename(pool = !!sym(pool_var))
 
-  if(dv %in% colnames(raw_data)){
+  # normalize dv by pool
+  raw_data = raw_data  %>%
+    group_by(!!sym(pool_var)) %>%
+    mutate(temp_dv_var = !!sym(dv)) %>%
+    mutate(temp_dv_var = temp_dv_var / mean(temp_dv_var, na.rm = TRUE)) %>%
+    mutate(temp_dv_var = if_else(is.na(temp_dv_var), 0, temp_dv_var))
+  raw_data[dv] = raw_data %>%
+    pull(temp_dv_var)
+  raw_data = raw_data %>%
+    select(-temp_dv_var)
 
-    pool_mean = raw_data %>%
-      group_by(!!sym(pool_variable)) %>%
-      summarise(mean = mean(!!sym(dv))) %>%
-      rename(pool = !!sym(pool_variable))
-
-  }
-
-  # remove the pool variable from the others
-  variable = variable[variable != pool_variable]
-
-  # for each variable
-  for (var in variable) {
-    # get that variable's transformation
-    transformation = meta_data$meta[meta_data$variable == var] %>% toupper()
-
-    # if STA apply pooled sta
-    if (transformation == "STA") {
-      raw_data = raw_data %>%
-        group_by(!!sym(pool_variable)) %>%
-        mutate(var = !!sym(var) / mean(!!sym(var), na.rm = TRUE)) %>%
-        mutate(var = if_else(is.na(var), 0, var))
-
-      # replace the raw variable with the STAed variable
-      raw_data[, var] = raw_data[, "var"]
-      raw_data[, "var"] = NULL
-
-    }
-
-  }
   return(list(data = raw_data,pool_mean = pool_mean))
 }
 
@@ -199,57 +99,80 @@ apply_normalisation = function(raw_data = NULL,
 #' Transform data based on the model table by applying the transformation functions (e.g. \code{decay}, \code{diminish}, \code{lag}, and \code{ma}) with the specified parameters to the respective variable
 #'
 #' @export
-#' @param data \code{data.frame} containing data for analysis
-#' @param model_table \code{data.frame} as created in the \code{build_model_table} function
+#' @param raw_data \code{data.frame} containing data for analysis
 #' @param trans_df \code{data.frame} defining the non-linear transformations to apply
-#' @param meta_data \code{data.frame} mapping variable names to their roles (i.e. POOL)
+#' @param model_table \code{data.frame} as created in the \code{build_model_table} function
+#' @param pool_var string specifying the pool variable name (e.g. 'country')
 #' @param verbose A boolean to specify whether to print warnings
-#' @return \code{tibble} of raw_data with added transformed variables
-apply_transformation = function(data = NULL,
+#' @return \code{data.frame} of raw_data with added transformed variables
+#' @examples
+#'
+#' pooled_data = read_xcsv(
+#'  verbose = FALSE,
+#'  file = "https://raw.githubusercontent.com/paladinic/data/main/pooled%20data.csv")
+#'
+#'
+#' model_table = build_model_table('christmas')
+#' model_table['decay'] = '0.5'
+#'
+#' trans_data = apply_transformation(
+#'  raw_data = pooled_data,
+#'  model_table = model_table,
+#'  pool_var = 'country')
+#'
+apply_transformation = function(raw_data = NULL,
                                 model_table = NULL,
                                 trans_df = NULL,
-                                meta_data = NULL,
+                                pool_var = NULL,
                                 verbose = FALSE) {
   # checks  #####
 
   # check verbose
   if(!is.logical(verbose)){
-    message("Warning: verbose provided must be logical (TRUE or FALSE). Setting to False.")
+    message("Warning: verbose provided must be logical (TRUE or FALSE). Setting to FALSE.")
     verbose = FALSE
   }
 
   # check model table provided (not NULL)
-  if(is.null(data)){
+  if(is.null(raw_data)){
     if(verbose){
       message("Error: No data provided for transformations. Returning NULL.")
     }
     return(NULL)
   }
-  if(!is.data.frame(data)){
+  if(!is.data.frame(raw_data)){
     if(verbose){
-      message("Error: data provided must be a data.frame. Returning NULL.")
+      message("Error: raw_data provided must be a data.frame. Returning NULL.")
     }
     return(NULL)
   }
 
-  # check model table provided (not NULL)
+  # check model_table provided (not NULL)
   if(is.null(model_table)){
     if(verbose){
-      message("Warning: No model table provided for transformations. Returning raw data.")
+      message("Warning: No model_table provided for transformations. Returning raw_data.")
     }
-    return(data)
+    return(raw_data)
   }
   if(!is.data.frame(model_table)){
     if(verbose){
-      message("Warning: model table provided must be a data.frame. Returning raw data.")
+      message("Warning: model_table provided must be a data.frame. Returning raw_data.")
+    }
+    return(raw_data)
+  }
+  else{
+    if(!("variable" %in% colnames(model_table))){
+      if(verbose){
+        message("Warning: model_table provided must contain a column called 'variable'. Returning raw_data.")
+      }
+      return(raw_data)
     }
-    return(data)
   }
 
   # check trans_df
   if(is.null(trans_df)){
     if(verbose){
-      message("Warning: no trans_df provided. Setting default trans_df.")
+      message("Warning: No trans_df provided. Setting default trans_df.")
     }
     trans_df = default_trans_df()
   }
@@ -260,6 +183,24 @@ apply_transformation = function(data = NULL,
     trans_df = default_trans_df()
   }
 
+  # check pool_var
+  if(is.null(pool_var)){
+
+    if (verbose) {
+      message("Warning: No pool_var provided. A new `total_pool` variable will be generated.")
+    }
+    pool_var = 'total_pool'
+    raw_data[pool_var] = pool_var
+
+  }
+  if(!(pool_var %in% colnames(raw_data))){
+    if(verbose){
+      message("Warning: pool variable not found in raw_data. A new `total_pool` variable will be generated.")
+    }
+    pool_var = 'total_pool'
+    raw_data[pool_var] = pool_var
+  }
+
   # get variables from model table
   model_table = model_table %>%
     get_variable_t(trans_df = trans_df)
@@ -268,75 +209,6 @@ apply_transformation = function(data = NULL,
   variable = model_table$variable
   trans = trans_df$name
 
-  # if a meta table is provided try to extract the POOL variable
-  if(is.null(meta_data)| !is.data.frame(meta_data)){
-    # else create a pool variable "total"...
-    if(verbose){
-      if(is.null(meta_data)){
-        message("Info: no meta_data provided. No groups (i.e. POOLs) used in transformations.")
-      }
-      if(!is.null(meta_data) & !is.data.frame(meta_data)){
-        message("Warning: meta_data provided must be a data.frame. No groups (i.e. POOLs) used in transformations.")
-      }
-    }
-    pool = "total_pool"
-    # ...and add it to the data
-
-    # if default pool variable already in use replace it
-    if(pool %in% colnames(data)){
-      if(verbose){
-        message("Info: 'total_pool' variable will be added/replaced from data.")
-      }
-
-      data$total_pool = NULL
-
-    }
-
-    data = tibble(data, total_pool = pool)
-
-  } else if (!is.null(meta_data)) {
-    pool = TRY({
-      meta_data %>%
-        filter(meta == "POOL") %>%
-        pull(variable)
-    })
-
-    # if there is a pool variable in the meta data...
-    # ...but has zero
-    if (!is.null(pool)) {
-      if (length(pool) == 0) {
-        if(verbose)print("Warning: no pool variable found in meta_data")
-        pool = "total_pool"
-
-        # if default pool variable already in use replace it
-        if(pool %in% colnames(data)){
-          if(verbose)print("Warning: 'total_pool' variable will be added/replaced from data")
-
-          data$total_pool = NULL
-
-        }
-
-        data = tibble(data, total_pool = pool)
-      }
-    } else{
-      # else create a pool variable "total"...
-      if(verbose)print("Warning: no pool variable found in meta_data")
-
-      # if default pool variable already in use replace it
-      if("total_pool" %in% colnames(data)){
-        if(verbose)print("Warning: 'total_pool' variable will be added/replaced from data")
-
-        data$total_pool = NULL
-
-      }
-
-      pool = "total_pool"
-      # ...and add it to the data
-      data = tibble(data, total_pool = pool)
-
-    }
-  }
-
   # process ####
 
   # for each variable...
@@ -350,8 +222,7 @@ apply_transformation = function(data = NULL,
       next
     }
 
-    # data[,var_t_name] = data[,var_name]
-    data[,'temp_var'] = data[,var_name]
+    raw_data[,'temp_var'] = raw_data[,var_name]
 
     # for each transformation on trans_df
     for(j in 1:nrow(trans_df)){
@@ -380,24 +251,24 @@ apply_transformation = function(data = NULL,
 
       }
 
-      groups = data %>%
-        pull(!!sym(pool)) %>%
+      groups = raw_data %>%
+        pull(!!sym(pool_var)) %>%
         unique()
 
       for(g in groups){
 
-        x = data$temp_var[data[,pool]==g]
+        x = raw_data$temp_var[raw_data[,pool_var]==g]
         x = t_func %>% run_text(env = e)
-        data$temp_var[data[,pool]==g] = x
+        raw_data$temp_var[raw_data[,pool_var]==g] = x
 
       }
     }
 
-    data[,var_t_name] = data[,'temp_var']
-    data[,'temp_var'] = NULL
+    raw_data[,var_t_name] = raw_data[,'temp_var']
+    raw_data[,'temp_var'] = NULL
   }
 
-  return(data)
+  return(raw_data)
 
 }
 
@@ -424,7 +295,7 @@ vapply_transformation = function(v,trans_df = NULL,verbose = FALSE){
   # check trans_df
   if (is.null(trans_df)) {
     if (verbose) {
-      message("Warning: no trans_df provided. Setting default trans_df.")
+      message("Warning: No trans_df provided. Setting default trans_df.")
     }
     trans_df = default_trans_df() %>%
       mutate(params = '')
@@ -467,7 +338,7 @@ vapply_transformation = function(v,trans_df = NULL,verbose = FALSE){
 #'
 #' Run a linear regression model
 #'
-#' Run a linear regression model that captures the transformations applied in the \code{model_table} and the normalisation described in the \code{meta_data}.
+#' Run a linear regression model that captures the transformations applied in the \code{model_table} and the normalisation based on the \code{pool_var}.
 #' A model can be run also by only supplying a dependent variable name \code{dv}, a vector of independent variable names dependent variable \code{ivs}, and the data that contains these.
 #'
 #' @export
@@ -475,18 +346,20 @@ vapply_transformation = function(v,trans_df = NULL,verbose = FALSE){
 #' @param dv string of the dependent variable name
 #' @param ivs character vector of the independent variables names
 #' @param trans_df \code{data.frame} defining the non-linear transformations to apply
-#' @param meta_data \code{data.frame} mapping variable names to their roles (i.e. POOL)
 #' @param id_var string of id variable name (e.g. date)
 #' @param model_table \code{data.frame} as created in the \code{build_model_table} function
 #' @param verbose A boolean to specify whether to print warnings
 #' @param normalise_by_pool A boolean to specify whether to apply the normalisation
-#' @param save_raw_data A boolean to specify whether to save all input data variables to the model object
+#' @param pool_var string specifying the pool variable name (e.g. 'country')
+#' @param save_all_raw_data A boolean to specify whether to save whole input data to the model object
 #' @param decompose A boolean to specify whether to generate the model decomposition
+#' @param tail_window for time series, length of tail in decomposition
 #' @param categories \code{data.frame} mapping variables to groups
 #' @import tidyverse
 #' @import tibble
 #' @import zoo
 #' @importFrom stats lm na.omit
+#' @importFrom car vif
 #' @return Model object
 #' @examples
 #'
@@ -516,29 +389,81 @@ run_model = function(data = NULL,
                      dv = NULL,
                      ivs = NULL,
                      trans_df = NULL,
-                     meta_data = NULL,
                      id_var = NULL,
+                     pool_var = NULL,
                      model_table = NULL,
                      verbose = FALSE,
                      normalise_by_pool = FALSE,
-                     save_raw_data = TRUE,
+                     save_all_raw_data = TRUE,
                      decompose = TRUE,
+                     tail_window = NULL,
                      categories = NULL) {
+  # test    ####
 
-  #
-  #   data = read_xcsv("https://raw.githubusercontent.com/paladinic/data/main/ecomm_data.csv")
-  #   dv = 'ecommerce'
-  #   ivs = c('christmas','black.friday')
-  #   trans_df = NULL
-  # meta_data = NULL
+  # data = read_xcsv("https://raw.githubusercontent.com/paladinic/data/main/ecomm_data.csv")
+  # dv = 'ecommerce'
+  # ivs = c('christmas')
+  # pool_var = NULL
+  # trans_df = NULL
   # id_var = NULL
   # model_table = NULL
   # verbose = T
+  # tail_window = NULL
   # normalise_by_pool = FALSE
-  # save_raw_data = TRUE
+  # save_all_raw_data = TRUE
   # decompose = TRUE
   # categories = NULL
 
+  # data = mtcars
+  # dv = 'mpg'
+  # ivs = c('wt','cyl','disp')
+  # pool_var = NULL
+  # trans_df = NULL
+  # id_var = NULL
+  # model_table = build_model_table(ivs = ivs) %>%
+  #   mutate(fixed = if_else(variable == 'wt','3',''))
+  # verbose = T
+  # tail_window = NULL
+  # normalise_by_pool = FALSE
+  # save_all_raw_data = TRUE
+  # decompose = TRUE
+  # categories = NULL
+  
+  # data = read_xcsv("https://raw.githubusercontent.com/paladinic/data/main/ecomm_data.csv")
+  # dv = 'ecommerce'
+  # ivs = c('christmas','black.friday')
+  # verbose = T
+  # tail_window = NULL
+  # normalise_by_pool = FALSE
+  # save_all_raw_data = TRUE
+  # decompose = TRUE
+  # categories = NULL
+  # model_table = NULL
+  # pool_var = NULL
+  # id_var = NULL
+  # 
+  # trans_df = data.frame(
+  #   name = c('diminish', 'decay', 'hill', 'exp'),
+  #   ts = c(FALSE,TRUE,FALSE,FALSE),
+  #   func = c(
+  #     'linea::diminish(x,a)',
+  #     'linea::decay(x,a)',
+  #     "linea::hill_function(x,a,b,c)",
+  #     '(x^a)'
+  #   ),
+  #   order = 1:4
+  # ) %>%
+  #   dplyr::mutate(offline_media = dplyr::if_else(condition = name == 'hill',
+  #                                                '(1,50),(1),(1,100)',
+  #                                                '')) %>%
+  #   dplyr::mutate(offline_media = dplyr::if_else(condition = name == 'decay',
+  #                                               '.1,.7 ',
+  #                                               offline_media)) %>%
+  #   dplyr::mutate(online_media = dplyr::if_else(condition = name == 'decay',
+  #                                               '.1,.7 ',
+  #                                               '')) %>%
+  #   dplyr::mutate(promo = '')
+  
   # checks  ####
 
   if (!is.logical(verbose)) {
@@ -558,33 +483,58 @@ run_model = function(data = NULL,
 
   # check dv is not provided
   if (is.null(dv)) {
-    message("Error: no dependent variable ('dv') provided. Returning NULL.")
+    message("Error: No dependent variable ('dv') provided. Returning NULL.")
     return(NULL)
   }
 
-  # check meta_data
-  if (is.null(meta_data)) {
-    if (verbose) {
-      message("Info: No meta_data provided for transformations and normalisation.")
+  # check pool_var
+  if(is.null(pool_var)){
+
+    if(verbose){
+      message("Warning: No pool_var provided. A new `total_pool` variable will be generated.")
     }
-  } else if (!is.data.frame(meta_data)) {
-    if (verbose) {
-      message(
-        "Warning: meta_data provided must be a data.frame. Not using 'meta_data' provided for transformations and normalisation."
-      )
+
+    pool_var = 'total_pool'
+    data[pool_var] = pool_var
+
+  }
+  if(!(pool_var %in% colnames(data))){
+    if(verbose){
+      message("Warning: pool variable not found in data. A new `total_pool` variable will be generated.")
     }
-  } else if (nrow(meta_data) == 0) {
-    if (verbose) {
-      message(
-        "Warning: meta_data provided has zero rows. Not using 'meta_data' provided for transformations and normalisation."
-      )
+    pool_var = 'total_pool'
+    data[pool_var] = pool_var
+  }
+
+  # check id_var
+  if(is.null(id_var)){
+    if(verbose){
+      message('Warning: No id_var supplied. Generating a new `id_var` in data')
     }
+
+    id_var = 'id'
+
+    data = data %>%
+      group_by(!!sym(pool_var)) %>%
+      mutate(id = row_number()) %>%
+      ungroup()
+  } else if(!(id_var %in% colnames(data))){
+    if(verbose){
+      message('Warning: id_var provided not found in data. Generating a new `id_var` in data')
+    }
+
+    id_var = 'id'
+
+    data = data %>%
+      group_by(!!sym(pool_var)) %>%
+      mutate(id = row_number()) %>%
+      ungroup()
   }
 
   # check trans_df
   if (is.null(trans_df)) {
     if (verbose) {
-      message("Warning: no trans_df provided. Setting default trans_df.")
+      message("Warning: No trans_df provided. Setting default trans_df.")
     }
     trans_df = default_trans_df()
   } else{
@@ -608,7 +558,7 @@ run_model = function(data = NULL,
   # if model_table and ivs not provided
   if (is.null(model_table) & is.null(ivs)) {
     message(
-      "Error: no independent variable, 'ivs' nor 'model_table', provided. Returning NULL."
+      "Error: No independent variable, 'ivs' nor 'model_table', provided. Returning NULL."
     )
     return(NULL)
   }
@@ -620,7 +570,7 @@ run_model = function(data = NULL,
     }
     if (!is.data.frame(model_table)) {
       if (is.null(ivs)) {
-        message("Error: no 'ivs' nor 'model_table' provided. Returning NULL.")
+        message("Error: No 'ivs' nor 'model_table' provided. Returning NULL.")
         return(NULL)
       } else{
         message("Warning: 'model_table' must be a data.frame. Using 'ivs' argument instead.")
@@ -630,8 +580,9 @@ run_model = function(data = NULL,
       model_table = model_table %>%
         get_variable_t(excl_blanks = TRUE, trans_df = trans_df)
 
-      ivs = model_table %>% pull(variable) %>% unique()
-      ivs_t = model_table %>% pull(variable_t) %>% unique()
+      ivs = model_table %>% filter(fixed=='') %>% pull(variable) %>% unique()
+      ivs_t = model_table %>% filter(fixed=='') %>% pull(variable_t) %>% unique()
+      fixed_ivs_t = model_table %>% filter(fixed!='')  %>% pull(variable_t) %>% unique()
     }
   } else{
     model_table = build_model_table(ivs = ivs, trans_df = trans_df)
@@ -640,30 +591,22 @@ run_model = function(data = NULL,
       get_variable_t(excl_blanks = TRUE, trans_df = trans_df) %>% unique()
 
     ivs_t = model_table %>% pull(variable_t) %>% unique()
+    fixed_ivs_t = NULL
   }
 
 
-
-
   # check categories in model_table
   if (!('category' %in% colnames(model_table))) {
     model_table$category = ""
   }
 
-  # formula ####
-
-  # build formula object
-  formula = build_formula(dv = dv, ivs = ivs_t)
-
-
   # data    ####
 
   # generate norm_data
   if (normalise_by_pool) {
     norm_data = apply_normalisation(
       raw_data = data,
-      model_table =  model_table,
-      meta_data = meta_data,
+      pool_var = pool_var,
       dv = dv,
       verbose = verbose
     )
@@ -671,37 +614,60 @@ run_model = function(data = NULL,
     norm_data = data
   }
 
-  # check norm_data
+  # check norm_data for pool_mean
   if (length(norm_data) == 2) {
     pool_mean = norm_data$pool_mean
     norm_data = norm_data$data
   }
 
   trans_data = apply_transformation(
-    data = norm_data,
+    raw_data = norm_data,
     trans_df = trans_df,
     model_table = model_table,
-    meta_data = meta_data,
+    pool_var = pool_var,
     verbose = verbose
   )
 
+  # formula ####
+
+  # build formula object
+  formula = build_formula(dv = dv,
+                          model_table = model_table,
+                          trans_df = trans_df)
+  
   # model   ####
+  
+  # run model
 
-  # run model on norm_data
-  model = lm(formula = formula, data = trans_data[, c(dv, ivs_t)])
-
-  # add meta_data to mdoel object
-  model$meta_data = meta_data
+  model = lm(
+    formula = formula,
+    data = trans_data[, c(dv, ivs_t, fixed_ivs_t)]
+  )
 
   # set colnames as ivs. bypass backticks added to ivs by lm()
   names(model$coefficients) = c("(Intercept)", ivs_t)
   colnames(model$qr$qr) = c("(Intercept)", ivs_t)
-  #names(model$effects)[1:(length(ivs_t))] = c("(Intercept)", ivs)
 
-  # add dv, trans_df, and model_table to mdoel object
-  model$dv = dv # add dv and model_table to mdoel object
+  if(length(ivs_t)>1){
+    vif_df = car::vif(model)
+    
+  }else{
+    vif_df = c(vif='0')
+  }
+  vif_df = data.frame(vif = vif_df,
+                      variable = names(vif_df))
+  
+  if(exists('pool_mean')){
+    model$pool_mean = pool_mean
+  }
+  
+  model$id_var = id_var
+  model$tail_window = tail_window
+  model$pool_var = pool_var
+  model$dv = dv
   model$trans_df = trans_df
   model$model_table = model_table
+  model$normalise_by_pool = normalise_by_pool
 
   output_model_table = model_table %>%
     filter(variable != "") %>%
@@ -741,35 +707,28 @@ run_model = function(data = NULL,
       p_value = as.numeric(p_value),
       category = as.character(category)
     ) %>%
-    mutate(category = if_else(variable == "(Intercept)", "Base", category))
+    mutate(category = if_else(variable == "(Intercept)", "Base", category)) %>% 
+    left_join(vif_df,by = ('variable_t'='variable'),suffix = c('',''))
 
   # create moodel output table with tran's and stats's (e.g. tstats)
   model$output_model_table = output_model_table
 
 
-  if (exists("pool_mean")) {
-    model$pool_mean = pool_mean
+  if(save_all_raw_data) {
+    model$raw_data = data
+  }else{
+    model$raw_data = data[,c(id_var,pool_var,dv,ivs)]
   }
 
-  if (exists("id_var")) {
-    model$id_var = id_var
-  }
-
-  if (save_raw_data) {
-    model$data = data
-  }
-
-  model$normalise_by_pool = normalise_by_pool
-
   # decomp  ####
+
   if (decompose) {
     decomp_list = decomping(
+      tail_window = tail_window, 
       model = model,
-      raw_data = data,
       de_normalise = normalise_by_pool,
       categories = categories,
-      verbose = verbose,
-      id_var = id_var
+      verbose = verbose
     ) %>% TRY()
 
     if (is.null(decomp_list)) {
@@ -798,8 +757,8 @@ run_model = function(data = NULL,
 #' @param dv string of the dependent variable name
 #' @param ivs character vector of the independent variables names
 #' @param trans_df \code{data.frame} defining the non-linear transformations to apply
-#' @param meta_data \code{data.frame} mapping variable names to their roles (i.e. POOL)
 #' @param id_var string of id variable name (e.g. date)
+#' @param pool_var string of pool variable name (e.g. country)
 #' @param model_table \code{data.frame} as created in the \code{build_model_table} function
 #' @param verbose A boolean to specify whether to print warnings
 #' @param normalise_by_pool A boolean to specify whether to apply the normalisation
@@ -810,18 +769,15 @@ run_model = function(data = NULL,
 #' @importFrom stats lm na.omit
 #' @return Model object
 #' @examples
-#' model = run_model(
-#'    data = read_xcsv("https://raw.githubusercontent.com/paladinic/data/main/ecomm_data.csv"),
-#'    dv = 'ecommerce',
-#'    ivs = c('christmas','black.friday'))
+#' model = run_model(mtcars,ivs = 'cyl', dv = 'mpg',save_all_raw_data = TRUE)
 #' re_run_model(model,ivs = c('disp','cyl','wt'))
 re_run_model = function(model,
                         data = NULL,
                         dv = NULL,
                         ivs = NULL,
                         trans_df = NULL,
-                        meta_data = NULL,
                         id_var = NULL,
+                        pool_var = NULL,
                         model_table = NULL,
                         normalise_by_pool = FALSE,
                         verbose = FALSE,
@@ -849,26 +805,38 @@ re_run_model = function(model,
 
   # set defaults where needed
   if(is.null(data)){
-    data = model$data
+    data = model$raw_data
   }
   if(is.null(dv)){
     dv = model$dv
   }
-  if(is.null(ivs)){
+
+  if(is.null(ivs) & is.null(model_table)){
+    model_table = model$model_table
+
     ivs = model$ivs
   }
+  else if(!is.null(model_table)){
+    if(!is.null(ivs)){
+      if(verbose){
+        message('Warning: both model_table and ivs have been supplied. model_table will be used.')
+      }
+    }
+    ivs = NULL
+  }
+  else if(!is.null(ivs)){
+    model_table = NULL
+  }
+
   if(is.null(trans_df)){
     trans_df = model$trans_df
   }
-  if(is.null(meta_data)){
-    meta_data = model$meta_data
+  if(is.null(pool_var)){
+    pool_var = model$pool_var
   }
   if(is.null(id_var)){
     id_var = model$id_var
   }
-  if(is.null(model_table)){
-    model_table = model$model_table
-  }
   if(is.null(normalise_by_pool)){
     normalise_by_pool = model$normalise_by_pool
   }
@@ -878,7 +846,6 @@ re_run_model = function(model,
             dv = dv,
             ivs = ivs,
             trans_df = trans_df,
-            meta_data = meta_data,
             id_var = id_var,
             model_table = model_table,
             normalise_by_pool = normalise_by_pool,
