@@ -111,6 +111,7 @@ build_model_table = function(ivs,trans_df = NULL,ts = TRUE){
   model_table = data.frame(matrix(ncol = length(cols), nrow = rows,data = ''))
   colnames(model_table) = cols
   model_table$variable = ivs
+  model_table$fixed = ''
 
   return(model_table)
 
@@ -131,7 +132,7 @@ build_model_table = function(ivs,trans_df = NULL,ts = TRUE){
 #' @import dplyr
 #' @return \code{tibble} of model table with added variable_t column
 #' @examples
-#' build_model_table(colnames(mtcars)) %>%
+#' model_table = build_model_table(colnames(mtcars)) %>%
 #'    get_variable_t()
 get_variable_t = function(model_table,
                           excl_intercept = TRUE,
@@ -146,8 +147,8 @@ get_variable_t = function(model_table,
   if (excl_intercept) {
     model_table = model_table %>%
       filter(variable != "(Intercept)")
-
   }
+  
   if (excl_blanks) {
     model_table = model_table %>%
       filter(variable != "") %>%
@@ -185,26 +186,71 @@ get_variable_t = function(model_table,
 #' @param dv string of dependent variable name
 #' @param ivs character vector of independent variable names
 #' @param model_table \code{tibble}/ \code{data.frame} as created in the \code{build_model_table} function
+#' @param trans_df \code{data.frame} defining the non-linear transformations to apply
 #' @import dplyr
 #' @importFrom stats formula
 #' @return a \code{formula} object
-build_formula = function(dv, ivs, model_table = NULL) {
+build_formula = function(dv, ivs, model_table = NULL, trans_df = NULL) {
 
   if(!is.null(model_table)){
-
-    model_table = get_variable_t(model_table)
-
+    
+    if(is.null(trans_df)){
+      trans_df = default_trans_df()
+    }
+    
+    model_table = get_variable_t(model_table,trans_df = trans_df)
+    
     ivs = model_table %>%
-      pull(variable_t)
-
-  }
-  else{
+      filter(fixed == '') %>% # remove variables with fixed coefficients
+      pull(variable_t) # extract variable names
+    
+    fixed_ivs = model_table %>%
+      filter(fixed != '') %>% # remove variables with fixed coefficients
+      pull(variable_t) # extract variable names
+    
+    if(length(fixed_ivs)==0){
+      f = formula(paste0("`",
+                         dv,
+                         "` ~ `",
+                         paste0(ivs,
+                                collapse = "` + `"),
+                         "`"))
+      return(f)
+    }
+    
+    fixed_coef = model_table %>%
+      filter(fixed != '') %>% # remove variables with fixed coefficients
+      pull(fixed) # extract variable names
+    
+    if(length(ivs)==0){
+      f = formula(paste0("`",
+                         dv,
+                         "` ~ ",
+                         paste0(
+                           'offset(', paste0(fixed_coef, " * `", fixed_ivs), '`)', collapse = ' + '
+                         )))
+      return(f)
+    }
+    
+    f = formula(paste0(
+      "`",
+      dv,
+      "` ~ `",
+      paste0(ivs,
+             collapse = "` + `"),
+      "`  + ",
+      paste0('offset(', paste0(fixed_coef, " * `", fixed_ivs), '`)', collapse = ' + ')
+    ))
+  }else{
     ivs = ivs[(!is.null(ivs))&(!is.na(ivs))&(ivs != "")]
+    
+    
+    f = formula(paste0("`",
+                       dv,
+                       "` ~ `",
+                       paste0(ivs,
+                              collapse = "` + `"),
+                       "`"))
   }
-  f = formula(paste0("`",
-                     dv,
-                     "` ~ `",
-                     paste0(ivs,
-                            collapse = "` + `"),
-                     "`"))
+  return(f)
 }
